@@ -25,6 +25,7 @@ from argparse import ArgumentParser
 from .discovery.files import (
     AndroidDiscovery,
     AppStoreDiscovery,
+    ARBDiscovery,
     ASSDiscovery,
     FluentDiscovery,
     GettextDiscovery,
@@ -43,6 +44,7 @@ from .discovery.files import (
     SRTDiscovery,
     SSADiscovery,
     SUBDiscovery,
+    TOMLDiscovery,
     WebExtensionDiscovery,
     XliffDiscovery,
     YAMLDiscovery,
@@ -54,6 +56,7 @@ BACKENDS = [
     TransifexDiscovery,
     AndroidDiscovery,
     AppStoreDiscovery,
+    ARBDiscovery,
     ASSDiscovery,
     FluentDiscovery,
     GettextDiscovery,
@@ -72,6 +75,7 @@ BACKENDS = [
     SRTDiscovery,
     SSADiscovery,
     SUBDiscovery,
+    TOMLDiscovery,
     WebExtensionDiscovery,
     XliffDiscovery,
     YAMLDiscovery,
