@@ -53,6 +53,8 @@ class GettextDiscovery(BaseDiscovery):
             pot_names = [
                 result["filemask"].replace("po/*/", "pot/") + "t",
                 result["filemask"].replace(".*", ""),
+                result["filemask"].replace("_*", ""),
+                result["filemask"].replace("-*", ""),
             ]
             for pot_name in pot_names:
                 if self.finder.has_file(pot_name):
@@ -109,7 +111,7 @@ class OSXDiscovery(EncodingDiscovery):
     """OSX string properties files discovery."""
 
     file_format = "strings"
-    encoding_map = {"utf-8": "strings-utf8"}
+    encoding_map = {"utf_8": "strings-utf8"}
 
     def get_masks(self):
         """Return all file masks found in the directory.
@@ -129,7 +131,7 @@ class JavaDiscovery(EncodingDiscovery):
     """Java string properties files discovery."""
 
     file_format = "properties"
-    encoding_map = {"utf-8": "properties-utf8", "utf-16": "properties-utf16"}
+    encoding_map = {"utf_8": "properties-utf8", "utf_16": "properties-utf16"}
     mask = "*_*.properties"
 
     def possible_templates(self, language, mask):
@@ -139,8 +141,7 @@ class JavaDiscovery(EncodingDiscovery):
 
 
 class RESXDiscovery(BaseDiscovery):
-    """RESX files discovery.
-    """
+    """RESX files discovery."""
 
     file_format = "resx"
     mask = "resources.res[xw]"
@@ -166,8 +167,7 @@ class RESXDiscovery(BaseDiscovery):
 
 
 class AppStoreDiscovery(BaseDiscovery):
-    """App store metadata.
-    """
+    """App store metadata."""
 
     file_format = "appstore"
 
@@ -236,6 +236,9 @@ class JSONDiscovery(BaseDiscovery):
                 data = json.load(handle)
             except ValueError:
                 return
+            if isinstance(data, list) and len(data) > 0 and "id" in data[0]:
+                result["file_format"] = "go-i18n-json"
+                return
             if not isinstance(data, dict):
                 return
 
@@ -360,3 +363,25 @@ class InnoSetupDiscovery(BaseDiscovery):
 
     file_format = "islu"
     mask = "*.islu"
+
+
+class TOMLDiscovery(BaseDiscovery):
+    """TOML files discovery."""
+
+    file_format = "toml"
+    mask = "*.toml"
+
+
+class ARBDiscovery(BaseDiscovery):
+    """ARB files discovery."""
+
+    file_format = "arb"
+    mask = "*.arb"
+
+    def fill_in_new_base(self, result):
+        super().fill_in_new_base(result)
+        if "intermediate" not in result:
+            # Flutter intermediate files
+            intermediate = result["filemask"].replace("*", "messages")
+            if self.finder.has_file(intermediate):
+                result["intermediate"] = intermediate
