@@ -25,14 +25,17 @@ from .discovery.base import DiscoveryResult
 from .discovery.files import (
     AndroidDiscovery,
     AppStoreDiscovery,
+    ARBDiscovery,
     FluentDiscovery,
     GettextDiscovery,
+    HTMLDiscovery,
     JavaDiscovery,
     JoomlaDiscovery,
     JSONDiscovery,
     OSXDiscovery,
     QtDiscovery,
     RESXDiscovery,
+    TOMLDiscovery,
     WebExtensionDiscovery,
     XliffDiscovery,
     YAMLDiscovery,
@@ -280,7 +283,6 @@ class GetttetTest(DiscoveryTestCase):
 
     def test_new_base(self):
         discovery = GettextDiscovery(self.get_finder(["foo.fr.po", "foo.po"]))
-        print(list(discovery.discover()))
         self.assert_discovery(
             discovery.discover(),
             [
@@ -294,6 +296,19 @@ class GetttetTest(DiscoveryTestCase):
             ],
         )
 
+    def test_po_pot(self):
+        discovery = GettextDiscovery(self.get_finder(["po/jasp_nl.po", "po/jasp.po"]))
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "po/jasp_*.po",
+                    "file_format": "po",
+                    "new_base": "po/jasp.po",
+                }
+            ],
+        )
+
 
 class QtTest(DiscoveryTestCase):
     def test_basic(self):
@@ -706,3 +721,68 @@ class YAMLDiscoveryTest(DiscoveryTestCase):
                 }
             ],
         )
+
+
+class TOMLDiscoveryTest(DiscoveryTestCase):
+    def test_basic(self):
+        discovery = TOMLDiscovery(
+            self.get_finder(
+                ["translations/en/messages.en.toml", "translations/de/messages.de.toml"]
+            )
+        )
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "translations/*/messages.*.toml",
+                    "file_format": "toml",
+                    "template": "translations/en/messages.en.toml",
+                }
+            ],
+        )
+
+
+class ARBDiscoveryTest(DiscoveryTestCase):
+    def test_basic(self):
+        discovery = ARBDiscovery(
+            self.get_finder(
+                [
+                    "lib/l10n/intl_en.arb",
+                    "lib/l10n/intl_messages.arb",
+                    "lib/l10n/intl_cs.arb",
+                    "res/values/strings_en.arb",
+                ]
+            )
+        )
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "lib/l10n/intl_*.arb",
+                    "file_format": "arb",
+                    "template": "lib/l10n/intl_en.arb",
+                    "intermediate": "lib/l10n/intl_messages.arb",
+                },
+                {
+                    "filemask": "res/values/strings_*.arb",
+                    "file_format": "arb",
+                    "template": "res/values/strings_en.arb",
+                },
+            ],
+        )
+
+
+class HTMLDiscoveryTest(DiscoveryTestCase):
+    def test_basic(self):
+        discovery = HTMLDiscovery(self.get_finder(["docs/en.html", "docs/cs.html"]))
+        self.assert_discovery(
+            discovery.discover(),
+            [
+                {
+                    "filemask": "docs/*.html",
+                    "file_format": "html",
+                    "template": "docs/en.html",
+                    "new_base": "docs/en.html",
+                },
+            ],
+        )
